@@ -96,7 +96,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
     const QStringList languages = Loader::openLoader()->languages();
     s_knownDictionaries = QSet<QString>(languages.begin(), languages.end());
     QSet<QString> dictionaryLanguages;
-    for (const QString &dictName : qAsConst(s_knownDictionaries)) {
+    for (const QString &dictName : std::as_const(s_knownDictionaries)) {
         QString languageName = QLocale(dictName).name();
         if (languageName.isEmpty()) {
             qCWarning(SONNET_LOG_CORE) << "Unable to parse name for dictionary" << dictName;
@@ -504,7 +504,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
 
         { // Remove unknown languages
             QStringList pruned;
-            for (const QString &name : qAsConst(names)) {
+            for (const QString &name : std::as_const(names)) {
                 if (!dictionaryLanguages.contains(name)) {
                     continue;
                 }
@@ -517,7 +517,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
             continue;
         }
 
-        for (const QString &name : qAsConst(names)) {
+        for (const QString &name : std::as_const(names)) {
             s_scriptLanguages.insert(script, name);
         }
     }
@@ -526,7 +526,7 @@ GuessLanguagePrivate::GuessLanguagePrivate()
     if (!allLanguages.contains(s_knownDictionaries)) {
         QSet<QString> dicts(s_knownDictionaries);
         dicts.subtract(allLanguages);
-        for (const QString &dictName : qAsConst(dicts)) {
+        for (const QString &dictName : std::as_const(dicts)) {
             QString languageName = QLocale(dictName).name();
             if (languageName.isEmpty()) {
                 qCWarning(SONNET_LOG_CORE) << "Unable to parse language name" << dictName;
@@ -577,8 +577,9 @@ QString GuessLanguage::identify(const QString &text, const QStringList &suggesti
     for (const QChar::Script script : scriptsList) {
         const auto languagesList = d->s_scriptLanguages.values(script);
         for (const QString &lang : languagesList) {
-            if (!d->s_knownModels.contains(lang))
+            if (!d->s_knownModels.contains(lang)) {
                 candidateLanguages.append(lang);
+            }
         }
     }
 
@@ -655,13 +656,12 @@ void GuessLanguagePrivate::loadModels()
 
 QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString &text)
 {
-    QChar::Script script = QChar::Script_Unknown;
     QHash<QChar::Script, int> scriptCounts;
 
     int totalCount = 0;
 
     for (const QChar c : text) {
-        script = c.script();
+        const QChar::Script script = c.script();
 
         if (script == QChar::Script_Common || script == QChar::Script_Inherited) {
             continue;
@@ -682,7 +682,7 @@ QList<QChar::Script> GuessLanguagePrivate::findRuns(const QString &text)
     }
 
     if (scriptCounts.size() == 1) {
-        return {script};
+        return {scriptCounts.cbegin().key()};
     }
 
     for (auto it = scriptCounts.cbegin(); it != scriptCounts.cend(); ++it) {
@@ -791,7 +791,7 @@ QVector<QString> GuessLanguagePrivate::createOrderedModel(const QString &content
 
     QVector<QString> orderedTrigrams;
     orderedTrigrams.reserve(trigramFrequencyList.size());
-    for (const auto &tri : qAsConst(trigramFrequencyList)) {
+    for (const auto &tri : std::as_const(trigramFrequencyList)) {
         orderedTrigrams.append(tri.second);
     }
 
